Struct AutoInsertApplyDeferredPass
pub struct AutoInsertApplyDeferredPass { /* private fields */ }Expand description
A ScheduleBuildPass that inserts ApplyDeferred systems into the schedule graph
when there are Deferred
in one system and there are ordering dependencies on that system. Commands is one
such deferred buffer.
This pass is typically automatically added to the schedule. You can disable this by setting
ScheduleBuildSettings::auto_insert_apply_deferred
to false. You may want to disable this if you only want to sync deferred params at the end of the schedule,
or want to manually insert all your sync points.